﻿using System.Security.Authentication;
using IdentityModel;
using XF.Domain.Authentications;
using XF.Domain.Dependency;
using XF.Utility.AppIdentityModel;

namespace Hotline.Api.Token
{
    public class DefaultSessionContext : ISessionContext, IScopeDependency
    {
        public DefaultSessionContext(IHttpContextAccessor httpContextAccessor)
        {
            var httpContext = httpContextAccessor.HttpContext;
            if (httpContext is null)
                throw new ArgumentNullException(nameof(httpContext));
            //var a = Thread.CurrentPrincipal as ClaimsPrincipal;
            var user = httpContext.User;
            UserId = user.Claims.FirstOrDefault(d => d.Type == JwtClaimTypes.Subject)?.Value;
            UserName = user.Claims.FirstOrDefault(d => d.Type == AppClaimTypes.UserDisplayName)?.Value;
            Roles = user.Claims.Where(d => d.Type == JwtClaimTypes.Role).Select(d => d.Value).ToArray();
            Phone = user.Claims.FirstOrDefault(d => d.Type == JwtClaimTypes.PhoneNumber)?.Value;
        }

        /// <summary>
        /// Id of current tenant or null for host
        /// </summary>
        public string? UserId { get; }

        /// <summary>
        /// Id of current user or throw Exception for guest
        /// </summary>
        /// <exception cref="AuthenticationException"></exception>
        public string RequiredUserId => UserId ?? throw new ArgumentException();

        public string? UserName { get; }

        public string? Phone { get; }

        /// <summary>
        /// Roles
        /// </summary>
        public string[] Roles { get; }

        /// <summary>
        /// Return the first value of the specific <see cref="claimType"/> claim type, otherwise null if the claim is not present.
        /// </summary>
        /// <param name="claimType"></param>
        /// <returns></returns>
        public string? FindFirstValue(string claimType)
        {
            throw new NotImplementedException();
        }
    }
}
